type Currency$1 = "CHF" | "EUR" | "PLN";
type CurrencyRates = Record<Currency$1, number>;

type Country = "PL" | "NL" | "DE";

type Cost = {
    value: number;
    currency: Currency$1;
};
type VehicleType = "CAR" | "MOTORCYCLE" | "TRUCK_SMALL" | "TRUCK" | "ELECTRIC_CAR" | "HYBRID_CAR" | "HYBRID_PLUG_IN" | "QUAD";
type VehicleData = {
    type: VehicleType;
    engineOver20CCM: boolean;
};
type CompanyVatData = {
    country: Country;
    isCompany: boolean;
};
type VehicleDataOutsideEu = {
    type: VehicleType;
    isOutsideEu: boolean;
};
type ExtraCostsData = {
    label: string;
    checked: boolean;
};
type ConfigCostValue = {
    cost: Cost;
};
type ConfigItemValues<T> = {
    value: T;
} & ConfigCostValue;
type ConfigItemKeys = "vat" | "provision" | "transport" | "customs-duty" | "excise-duty" | "input" | "extra-costs";
interface ConfigItem<T = undefined> {
    key: ConfigItemKeys;
    dependencies: Array<ConfigItemKeys>;
    label: string;
    result: (input: ConfigItemValues<T>) => Cost & {
        label?: string;
    };
}
type ConfigItems = ConfigItem<boolean> | ConfigItem | ConfigItem<VehicleData> | ConfigItem<VehicleDataOutsideEu> | ConfigItem<CompanyVatData>;

type ProvisionType = {
    threshold: Cost;
    percentageProvision: number;
    staticMinProvision?: Cost;
    staticMaxProvision?: Cost;
};
declare class ProvisionConfigItem implements ConfigItem {
    private readonly currencyRates;
    private readonly provisions;
    constructor(currencyRates: CurrencyRates, provisions: Array<ProvisionType>);
    key: ConfigItemKeys;
    label: string;
    dependencies: Array<ConfigItemKeys>;
    result(input: ConfigItemValues<undefined>): {
        value: number;
        currency: Currency$1;
    };
}

declare class IsCompanyVatConfigItem implements ConfigItem<CompanyVatData> {
    key: ConfigItemKeys;
    label: string;
    dependencies: Array<ConfigItemKeys>;
    result(input: ConfigItemValues<CompanyVatData>): {
        value: number;
        currency: Currency$1;
    };
}

type CalculatorCostLines = ConfigItemKeys;
interface ICalculator<T> {
    getFinalCost(input: Cost, values: T): {
        finalCost: Cost;
        costLines: Array<{
            key: CalculatorCostLines;
            cost: Cost;
        }>;
    };
}

type BasicCalculatorType = {
    isCompany: boolean;
    isManufacturedOutsideEu: boolean;
    isImportedFromEu: boolean;
    vehicleType: VehicleType;
    engineOver20CCM: boolean;
    extraCosts: Array<ExtraCostsData>;
    customDutyCountry: Country;
};
declare class BasicCalculator implements ICalculator<BasicCalculatorType> {
    private readonly config;
    private readonly currencyRates;
    private constructor();
    static create(config: Array<ConfigItems>, currencyRates: CurrencyRates): BasicCalculator;
    protected getSumOfDependencies(inputCostCurrency: Cost["currency"], dependencies: ConfigItem["dependencies"], costLines: Array<{
        key: CalculatorCostLines;
        cost: Cost;
    }>): {
        currency: Currency$1;
        value: number;
    };
    getFinalCost(cost: Cost, values: BasicCalculatorType): {
        finalCost: Cost;
        costLines: Array<{
            key: CalculatorCostLines;
            cost: Cost;
        }>;
    };
}

declare class ExtraCostConfigItem implements ConfigItem<boolean> {
    private readonly currencyRates;
    private readonly extraCost;
    readonly label: string;
    constructor(currencyRates: CurrencyRates, extraCost: Cost, label: string);
    key: ConfigItemKeys;
    dependencies: Array<ConfigItemKeys>;
    result(input: ConfigItemValues<boolean>): {
        label: string;
        value: number;
        currency: Currency$1;
    };
}

type CustomDutyExcise = {
    STANDARD: number;
    MOTORCYCLE: number;
};
declare enum CustomDutyExciseStandard {
    STANDARD = 0.1
}
declare class HasCustomDutyConfigItem implements ConfigItem<VehicleDataOutsideEu> {
    private readonly customDutyExcisePerVehicleType;
    readonly dependencies: Array<ConfigItemKeys>;
    constructor(customDutyExcisePerVehicleType?: CustomDutyExcise, dependencies?: Array<ConfigItemKeys>);
    key: ConfigItemKeys;
    label: string;
    result(input: ConfigItemValues<VehicleDataOutsideEu>): {
        value: number;
        currency: Currency$1;
    };
}

declare class HasExciseDutyConfigItem implements ConfigItem<VehicleData> {
    key: ConfigItemKeys;
    label: string;
    dependencies: Array<ConfigItemKeys>;
    result(input: ConfigItemValues<VehicleData>): {
        value: number;
        currency: Currency$1;
    };
}

declare class TransportConfigItem implements ConfigItem<VehicleData> {
    private readonly currencyRates;
    private readonly provision;
    constructor(currencyRates: CurrencyRates, provision: Record<VehicleType, Cost>);
    key: ConfigItemKeys;
    label: string;
    dependencies: Array<ConfigItemKeys>;
    result(input: ConfigItemValues<VehicleData>): {
        value: number;
        currency: Currency$1;
    };
}

declare const Calculator: {
    ProvisionConfigItem: typeof ProvisionConfigItem;
    IsCompanyVatConfigItem: typeof IsCompanyVatConfigItem;
    ExtraCostConfigItem: typeof ExtraCostConfigItem;
    HasCustomDutyConfigItem: typeof HasCustomDutyConfigItem;
    HasExciseDutyConfigItem: typeof HasExciseDutyConfigItem;
    TransportConfigItem: typeof TransportConfigItem;
    BasicCalculator: typeof BasicCalculator;
    CustomDutyExciseStandard: typeof CustomDutyExciseStandard;
};
declare const Currency: {
    convertCurrency: (value: number, from: Currency$1, to: Currency$1, config?: CurrencyRates) => number;
};

export { Calculator, Currency };
